/* $Id$ */
/*-
 * Copyright (c) 2003, 2004 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; You may only use version 2 of the License,
 * you have no option to use any other version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif
#ifdef HAVE_SYS_EVENT_H
#include <sys/event.h>
#endif
#ifdef HAVE_SYS_TIME_H
#include <sys/time.h>
#endif

#include <signal.h>

#include <glib.h>
#include <glib-object.h>

#include <xprefs-daemon/xprefs-main.h>

static GMainLoop *loop = NULL;

static void
sig_handler (int signo)
{
  xprefs_main_quit ();
}

static void
sig_register (void)
{
  signal (SIGINT, sig_handler);
  signal (SIGKILL, sig_handler);
  signal (SIGTERM, sig_handler);
}

static void
sig_unregister (void)
{
  signal (SIGINT, SIG_DFL);
  signal (SIGKILL, SIG_DFL);
  signal (SIGTERM, SIG_DFL);
}

void
xprefs_main_init (int *argc, char ***argv)
{
  g_return_if_fail (loop == NULL);

  /* initialize the GLib type system */
  g_type_init ();

  loop = g_main_loop_new (NULL, FALSE);
}

void
xprefs_main_run (void)
{
  g_return_if_fail (loop != NULL);

  sig_register ();
  g_main_loop_run (loop);
  sig_unregister ();
}

void
xprefs_main_quit (void)
{
  g_return_if_fail (loop != NULL);

  g_main_loop_quit (loop);
}


