/* $Id$ */
/*-
 * Copyright (c) 2003, 2004 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __XPREFS_XPREFS_DBUS_H__
#define __XPREFS_XPREFS_DBUS_H__

#include <dbus/dbus.h>

#include <xprefs/xprefs-entry.h>

DBUS_BEGIN_DECLS;

#define XPREFS_DBUS_SERVICE             "org.xfce.XPrefs"

#define XPREFS_DBUS_DATABASE_OBJECT     "/org/xfce/XPrefs/Database"
#define XPREFS_DBUS_DATABASE_INTERFACE  "org.xfce.XPrefs.Database"

#define XPREFS_DBUS_DATABASE_GET              "Get"
#define XPREFS_DBUS_DATABASE_SET              "Set"
#define XPREFS_DBUS_DATABASE_UNSET            "Unset"
#define XPREFS_DBUS_DATABASE_DIR_EXISTS       "DirExists"
#define XPREFS_DBUS_DATABASE_ALL_ENTRIES      "AllEntries"
#define XPREFS_DBUS_DATABASE_ALL_SUBDIRS      "AllSubdirs"
#define XPREFS_DBUS_DATABASE_LISTENER_ADD     "ListenerAdd"
#define XPREFS_DBUS_DATABASE_LISTENER_REMOVE  "ListenerRemove"

#define XPREFS_DBUS_LISTENER_INTERFACE    "org.xfce.XPrefs.Listener"
#define XPREFS_DBUS_LISTENER_NOTIFY       "Notify"

#define XPREFS_DBUS_ERROR_FAILED        "org.xfce.xprefs.Error.Failed"
#define XPREFS_DBUS_ERROR_INVALID_VALUE "org.xfce.xprefs.Error.InvalidValue"
#define XPREFS_DBUS_ERROR_PARSE_ERROR   "org.xfce.xprefs.Error.ParseError"
#define XPREFS_DBUS_ERROR_TYPE_MISMATCH "org.xfce.xprefs.Error.TypeMismatch"
#define XPREFS_DBUS_ERROR_BAD_KEY       "org.xfce.xprefs.Error.BadKey"
#define XPREFS_DBUS_ERROR_IS_DIR        "org.xfce.xprefs.Error.IsDir"
#define XPREFS_DBUS_ERROR_IS_KEY        "org.xfce.xprefs.Error.IsKey"

XPrefsEntry*  dbus_message_iter_get_xprefs_entry    (DBusMessageIter *iter);
XPrefsValue*  dbus_message_iter_get_xprefs_value    (DBusMessageIter *iter);

dbus_bool_t   dbus_message_iter_append_xprefs_entry (DBusMessageIter *iter,
                                                     const XPrefsEntry *entry);
dbus_bool_t   dbus_message_iter_append_xprefs_value (DBusMessageIter *iter,
                                                     const XPrefsValue *value);

dbus_bool_t   dbus_message_append_xprefs_value      (DBusMessage *message,
                                                     const XPrefsValue *value);

DBusMessage*  dbus_connection_send_and_process_reply(DBusConnection *connection,
                                                     DBusMessage *message,
                                                     DBusError *error);

DBUS_END_DECLS;

#endif  /* !__XPREFS_XPREFS_DBUS_H__ */

