/* $Id$ */
/*-
 * Copyright (c) 2003, 2004 Benedikt Meurer <benny@xfce.org>
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __XPREFS_XPREFS_VALUE_H__
#define __XPREFS_XPREFS_VALUE_H__

#include <glib.h>

G_BEGIN_DECLS;

typedef struct  _XPrefsValue      XPrefsValue;
typedef enum    _XPrefsValueType  XPrefsValueType;

enum _XPrefsValueType
{
  XPREFS_VALUE_INVALID,
  XPREFS_VALUE_BOOL,
  XPREFS_VALUE_DOUBLE,
  XPREFS_VALUE_INT,   /* always 32bit */
  XPREFS_VALUE_STRING,
};

#define XPREFS_VALUE_TYPE_VALID(type) ((type) > XPREFS_VALUE_INVALID && \
                                       (type) <= XPREFS_VALUE_STRING)

const gchar*    xprefs_value_type_to_string   (XPrefsValueType type);
XPrefsValueType xprefs_value_type_from_string (const gchar *type_str);


struct _XPrefsValue
{
  XPrefsValueType type;
};


XPrefsValue*  xprefs_value_new                (XPrefsValueType type);
XPrefsValue*  xprefs_value_new_from_string    (XPrefsValueType type,
                                               const gchar *value_str,
                                               GError **error);
XPrefsValue*  xprefs_value_copy               (const XPrefsValue *value);
void          xprefs_value_free               (XPrefsValue *value);

gchar*        xprefs_value_to_string          (const XPrefsValue *value);

gboolean      xprefs_value_get_bool           (const XPrefsValue *value);
gdouble       xprefs_value_get_double         (const XPrefsValue *value);
gint32        xprefs_value_get_int            (const XPrefsValue *value);
const gchar*  xprefs_value_get_string         (const XPrefsValue *value);

gchar*        xprefs_value_steal_string       (XPrefsValue *value);

void          xprefs_value_set_bool           (XPrefsValue *value,
                                               gboolean bool_data);
void          xprefs_value_set_double         (XPrefsValue *value,
                                               gdouble double_data);
void          xprefs_value_set_int            (XPrefsValue *value,
                                               gint32 int_data);
void          xprefs_value_set_string         (XPrefsValue *value,
                                               const gchar *string_data);
void          xprefs_value_set_string_nocopy  (XPrefsValue *value,
                                               gchar *string_data);

G_END_DECLS;

#endif  /* !__XPREFS_XPREFS_VALUE_H__ */
